summaryrefslogtreecommitdiffhomepage
path: root/pkg/sentry/fs/restore.go
diff options
context:
space:
mode:
authorNicolas Lacasse <nlacasse@google.com>2019-03-13 19:23:02 -0700
committerShentubot <shentubot@google.com>2019-03-13 19:24:03 -0700
commit2512cc561778b096459182b531eae4e0797e4ec5 (patch)
tree8efa41129f9df05827354432cc976a5427754319 /pkg/sentry/fs/restore.go
parentf97c4f1b7af1d4049c8f54a71cd611e42be46dee (diff)
Allow filesystem.Mount to take an optional interface argument.
PiperOrigin-RevId: 238360231 Change-Id: I5eaf8d26f8892f77d71c7fbd6c5225ef471cedf1
Diffstat (limited to 'pkg/sentry/fs/restore.go')
-rw-r--r--pkg/sentry/fs/restore.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/pkg/sentry/fs/restore.go b/pkg/sentry/fs/restore.go
index da2df7e1d..a6645b41e 100644
--- a/pkg/sentry/fs/restore.go
+++ b/pkg/sentry/fs/restore.go
@@ -41,8 +41,11 @@ type MountArgs struct {
// Flags corresponds to the flags argument of Mount.
Flags MountSourceFlags
- // Data corresponds to the data argument of Mount.
- Data string
+ // DataString corresponds to the data argument of Mount.
+ DataString string
+
+ // DataObj corresponds to the data interface argument of Mount.
+ DataObj interface{}
}
// restoreEnv holds the fs package global RestoreEnvironment.